# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Switch(Base):
	"""The Switch class encapsulates a user managed switch node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Switch property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'switch'

	def __init__(self, parent):
		super(Switch, self).__init__(parent)

	@property
	def BandTypes(self):
		"""An instance of the BandTypes class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.bandtypes.BandTypes)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.bandtypes import BandTypes
		return BandTypes(self)._select()

	@property
	def Capabilities(self):
		"""An instance of the Capabilities class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.capabilities.Capabilities)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.capabilities import Capabilities
		return Capabilities(self)._select()

	@property
	def FlowRemovedMaskMaster(self):
		"""An instance of the FlowRemovedMaskMaster class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.flowremovedmaskmaster.FlowRemovedMaskMaster)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.flowremovedmaskmaster import FlowRemovedMaskMaster
		return FlowRemovedMaskMaster(self)._select()

	@property
	def FlowRemovedMaskSlave(self):
		"""An instance of the FlowRemovedMaskSlave class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.flowremovedmaskslave.FlowRemovedMaskSlave)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.flowremovedmaskslave import FlowRemovedMaskSlave
		return FlowRemovedMaskSlave(self)._select()

	@property
	def GroupCapabilities(self):
		"""An instance of the GroupCapabilities class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.groupcapabilities.GroupCapabilities)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.groupcapabilities import GroupCapabilities
		return GroupCapabilities(self)._select()

	@property
	def GroupTypes(self):
		"""An instance of the GroupTypes class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.grouptypes.GroupTypes)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.grouptypes import GroupTypes
		return GroupTypes(self)._select()

	@property
	def MeterCapabilities(self):
		"""An instance of the MeterCapabilities class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.metercapabilities.MeterCapabilities)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.metercapabilities import MeterCapabilities
		return MeterCapabilities(self)._select()

	@property
	def PacketInMaskMaster(self):
		"""An instance of the PacketInMaskMaster class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.packetinmaskmaster.PacketInMaskMaster)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.packetinmaskmaster import PacketInMaskMaster
		return PacketInMaskMaster(self)._select()

	@property
	def PacketInMaskSlave(self):
		"""An instance of the PacketInMaskSlave class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.packetinmaskslave.PacketInMaskSlave)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.packetinmaskslave import PacketInMaskSlave
		return PacketInMaskSlave(self)._select()

	@property
	def PortStatusMaskMaster(self):
		"""An instance of the PortStatusMaskMaster class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.portstatusmaskmaster.PortStatusMaskMaster)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.portstatusmaskmaster import PortStatusMaskMaster
		return PortStatusMaskMaster(self)._select()

	@property
	def PortStatusMaskSlave(self):
		"""An instance of the PortStatusMaskSlave class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.portstatusmaskslave.PortStatusMaskSlave)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.portstatusmaskslave import PortStatusMaskSlave
		return PortStatusMaskSlave(self)._select()

	@property
	def SupportedActions(self):
		"""An instance of the SupportedActions class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.supportedactions.SupportedActions)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.supportedactions import SupportedActions
		return SupportedActions(self)._select()

	@property
	def SwitchGroupFeature(self):
		"""An instance of the SwitchGroupFeature class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchgroupfeature.SwitchGroupFeature)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchgroupfeature import SwitchGroupFeature
		return SwitchGroupFeature(self)

	@property
	def SwitchOfChannel(self):
		"""An instance of the SwitchOfChannel class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchofchannel.SwitchOfChannel)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchofchannel import SwitchOfChannel
		return SwitchOfChannel(self)

	@property
	def SwitchPacketIn(self):
		"""An instance of the SwitchPacketIn class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchpacketin.SwitchPacketIn)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchpacketin import SwitchPacketIn
		return SwitchPacketIn(self)

	@property
	def SwitchPorts(self):
		"""An instance of the SwitchPorts class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchports.SwitchPorts)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchports import SwitchPorts
		return SwitchPorts(self)

	@property
	def SwitchTables(self):
		"""An instance of the SwitchTables class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchtables.SwitchTables)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchtables import SwitchTables
		return SwitchTables(self)

	@property
	def BarrierReplyDelay(self):
		"""DEPRECATED Indicates the delay between successive barrier notifications.

		Returns:
			number
		"""
		return self._get_attribute('barrierReplyDelay')
	@BarrierReplyDelay.setter
	def BarrierReplyDelay(self, value):
		self._set_attribute('barrierReplyDelay', value)

	@property
	def BarrierReplyDelayType(self):
		"""DEPRECATED Select the delay type supported for barrier reply messages

		Returns:
			str(fixed|random)
		"""
		return self._get_attribute('barrierReplyDelayType')
	@BarrierReplyDelayType.setter
	def BarrierReplyDelayType(self, value):
		self._set_attribute('barrierReplyDelayType', value)

	@property
	def BarrierReplyMaxDelay(self):
		"""DEPRECATED Indicates the delay between successive barrier notifications.

		Returns:
			number
		"""
		return self._get_attribute('barrierReplyMaxDelay')
	@BarrierReplyMaxDelay.setter
	def BarrierReplyMaxDelay(self, value):
		self._set_attribute('barrierReplyMaxDelay', value)

	@property
	def CalculateControllerFlowTxRate(self):
		"""DEPRECATED If true, the Flow Rate of the controller is calculated.

		Returns:
			bool
		"""
		return self._get_attribute('calculateControllerFlowTxRate')
	@CalculateControllerFlowTxRate.setter
	def CalculateControllerFlowTxRate(self, value):
		self._set_attribute('calculateControllerFlowTxRate', value)

	@property
	def CalculatePacketInReplyDelay(self):
		"""DEPRECATED If true, calculates delay between Packet-In sent from Switch and reply received from Controller.

		Returns:
			bool
		"""
		return self._get_attribute('calculatePacketInReplyDelay')
	@CalculatePacketInReplyDelay.setter
	def CalculatePacketInReplyDelay(self, value):
		self._set_attribute('calculatePacketInReplyDelay', value)

	@property
	def DatapathDescription(self):
		"""DEPRECATED Indicates a description of datapath.

		Returns:
			str
		"""
		return self._get_attribute('datapathDescription')
	@DatapathDescription.setter
	def DatapathDescription(self, value):
		self._set_attribute('datapathDescription', value)

	@property
	def DatapathId(self):
		"""DEPRECATED Indicates the Datapath ID of the OpenFlow switch.

		Returns:
			str
		"""
		return self._get_attribute('datapathId')
	@DatapathId.setter
	def DatapathId(self, value):
		self._set_attribute('datapathId', value)

	@property
	def DatapathIdInHex(self):
		"""DEPRECATED Indicates the Datapath ID in hexadecimal format.

		Returns:
			str
		"""
		return self._get_attribute('datapathIdInHex')
	@DatapathIdInHex.setter
	def DatapathIdInHex(self, value):
		self._set_attribute('datapathIdInHex', value)

	@property
	def Description(self):
		"""DEPRECATED A description for the object.

		Returns:
			str
		"""
		return self._get_attribute('description')
	@Description.setter
	def Description(self, value):
		self._set_attribute('description', value)

	@property
	def Enable(self):
		"""DEPRECATED If true, the object is enabled.

		Returns:
			bool
		"""
		return self._get_attribute('enable')
	@Enable.setter
	def Enable(self, value):
		self._set_attribute('enable', value)

	@property
	def EnableCalculatePacketOutRxRate(self):
		"""DEPRECATED If enabled packet_out rx rate and packet_in tx rate will be caculated for the switch and shown in Aggregated Switch Statistics and Switch Learned Info. This field can be enabled only if Calculate PacketIn Reply Delay is disabled for the switch.

		Returns:
			bool
		"""
		return self._get_attribute('enableCalculatePacketOutRxRate')
	@EnableCalculatePacketOutRxRate.setter
	def EnableCalculatePacketOutRxRate(self, value):
		self._set_attribute('enableCalculatePacketOutRxRate', value)

	@property
	def EnableHelloElement(self):
		"""DEPRECATED If true, enables Hello element for version negotiation.

		Returns:
			bool
		"""
		return self._get_attribute('enableHelloElement')
	@EnableHelloElement.setter
	def EnableHelloElement(self, value):
		self._set_attribute('enableHelloElement', value)

	@property
	def HardwareDescription(self):
		"""DEPRECATED Indicates the hardware description of the switch.

		Returns:
			str
		"""
		return self._get_attribute('hardwareDescription')
	@HardwareDescription.setter
	def HardwareDescription(self, value):
		self._set_attribute('hardwareDescription', value)

	@property
	def InterPacketInBurstGap(self):
		"""DEPRECATED Indicates the duration, in milliseconds, to wait between successive Packet-In bursts.

		Returns:
			number
		"""
		return self._get_attribute('interPacketInBurstGap')
	@InterPacketInBurstGap.setter
	def InterPacketInBurstGap(self, value):
		self._set_attribute('interPacketInBurstGap', value)

	@property
	def LocalIp(self):
		"""DEPRECATED Indicates the local IP address of the interface. This field is auto-populated and cannot be changed.

		Returns:
			str
		"""
		return self._get_attribute('localIp')

	@property
	def ManufacturerDescription(self):
		"""DEPRECATED Indicates the description of the switch manufacturer.

		Returns:
			str
		"""
		return self._get_attribute('manufacturerDescription')
	@ManufacturerDescription.setter
	def ManufacturerDescription(self, value):
		self._set_attribute('manufacturerDescription', value)

	@property
	def MaxPacketInBytes(self):
		"""DEPRECATED Specifies the max amount of data to be sent in the Packet-In message.

		Returns:
			number
		"""
		return self._get_attribute('maxPacketInBytes')
	@MaxPacketInBytes.setter
	def MaxPacketInBytes(self, value):
		self._set_attribute('maxPacketInBytes', value)

	@property
	def MaximumColorValue(self):
		"""DEPRECATED Specify the maximum color value supported.The minimum value is 0 and the maximum value is 160. The default value is 50.

		Returns:
			number
		"""
		return self._get_attribute('maximumColorValue')
	@MaximumColorValue.setter
	def MaximumColorValue(self, value):
		self._set_attribute('maximumColorValue', value)

	@property
	def MaximumNoOfBandsPerMeter(self):
		"""DEPRECATED Specify the maximum number of bands supported per meter. The minimum value is 0 and the maximum value is 160. The default value is 50.

		Returns:
			number
		"""
		return self._get_attribute('maximumNoOfBandsPerMeter')
	@MaximumNoOfBandsPerMeter.setter
	def MaximumNoOfBandsPerMeter(self, value):
		self._set_attribute('maximumNoOfBandsPerMeter', value)

	@property
	def MaximumNoOfBucketsPerGroup(self):
		"""DEPRECATED Specify the maximum number of Buckets supported per group.The minimum value is 1 and the maximum value is 4092.The default value is 4092.

		Returns:
			number
		"""
		return self._get_attribute('maximumNoOfBucketsPerGroup')
	@MaximumNoOfBucketsPerGroup.setter
	def MaximumNoOfBucketsPerGroup(self, value):
		self._set_attribute('maximumNoOfBucketsPerGroup', value)

	@property
	def MaximumNoOfMeters(self):
		"""DEPRECATED Specify the maximum number of meters supported. The default value is 1000.

		Returns:
			number
		"""
		return self._get_attribute('maximumNoOfMeters')
	@MaximumNoOfMeters.setter
	def MaximumNoOfMeters(self, value):
		self._set_attribute('maximumNoOfMeters', value)

	@property
	def NumberOfBuffers(self):
		"""DEPRECATED Indicates the maximum number of packets that can be stored in the buffered at a time.

		Returns:
			number
		"""
		return self._get_attribute('numberOfBuffers')
	@NumberOfBuffers.setter
	def NumberOfBuffers(self, value):
		self._set_attribute('numberOfBuffers', value)

	@property
	def PacketInReplyTimeout(self):
		"""DEPRECATED Indicates the duration for which the Switch should wait for Packet-in-reply before freeing the buffer.

		Returns:
			number
		"""
		return self._get_attribute('packetInReplyTimeout')
	@PacketInReplyTimeout.setter
	def PacketInReplyTimeout(self, value):
		self._set_attribute('packetInReplyTimeout', value)

	@property
	def PacketInTxBurstSize(self):
		"""DEPRECATED Indicates the number of packets in messages sent in a single burst.

		Returns:
			number
		"""
		return self._get_attribute('packetInTxBurstSize')
	@PacketInTxBurstSize.setter
	def PacketInTxBurstSize(self, value):
		self._set_attribute('packetInTxBurstSize', value)

	@property
	def SerialNumber(self):
		"""DEPRECATED Indicates the Serial Number of the switch.

		Returns:
			str
		"""
		return self._get_attribute('serialNumber')
	@SerialNumber.setter
	def SerialNumber(self, value):
		self._set_attribute('serialNumber', value)

	@property
	def SoftwareDescription(self):
		"""DEPRECATED Indicates the description of the software installed on the switch.

		Returns:
			str
		"""
		return self._get_attribute('softwareDescription')
	@SoftwareDescription.setter
	def SoftwareDescription(self, value):
		self._set_attribute('softwareDescription', value)

	@property
	def StoreFlows(self):
		"""DEPRECATED If true, the switch will store the flows advertised by the controller in its tables.

		Returns:
			bool
		"""
		return self._get_attribute('storeFlows')
	@StoreFlows.setter
	def StoreFlows(self, value):
		self._set_attribute('storeFlows', value)

	@property
	def SupportPacketForwarding(self):
		"""DEPRECATED If true, indicates that Packet Forwarding is supported on the OpenFlow switch.

		Returns:
			bool
		"""
		return self._get_attribute('supportPacketForwarding')
	@SupportPacketForwarding.setter
	def SupportPacketForwarding(self, value):
		self._set_attribute('supportPacketForwarding', value)

	@property
	def TableMissAction(self):
		"""DEPRECATED Specify what the Switch should do when there is no match for the packets.

		Returns:
			str(drop|sendToController)
		"""
		return self._get_attribute('tableMissAction')
	@TableMissAction.setter
	def TableMissAction(self, value):
		self._set_attribute('tableMissAction', value)

	def update(self, BarrierReplyDelay=None, BarrierReplyDelayType=None, BarrierReplyMaxDelay=None, CalculateControllerFlowTxRate=None, CalculatePacketInReplyDelay=None, DatapathDescription=None, DatapathId=None, DatapathIdInHex=None, Description=None, Enable=None, EnableCalculatePacketOutRxRate=None, EnableHelloElement=None, HardwareDescription=None, InterPacketInBurstGap=None, ManufacturerDescription=None, MaxPacketInBytes=None, MaximumColorValue=None, MaximumNoOfBandsPerMeter=None, MaximumNoOfBucketsPerGroup=None, MaximumNoOfMeters=None, NumberOfBuffers=None, PacketInReplyTimeout=None, PacketInTxBurstSize=None, SerialNumber=None, SoftwareDescription=None, StoreFlows=None, SupportPacketForwarding=None, TableMissAction=None):
		"""Updates a child instance of switch on the server.

		Args:
			BarrierReplyDelay (number): Indicates the delay between successive barrier notifications.
			BarrierReplyDelayType (str(fixed|random)): Select the delay type supported for barrier reply messages
			BarrierReplyMaxDelay (number): Indicates the delay between successive barrier notifications.
			CalculateControllerFlowTxRate (bool): If true, the Flow Rate of the controller is calculated.
			CalculatePacketInReplyDelay (bool): If true, calculates delay between Packet-In sent from Switch and reply received from Controller.
			DatapathDescription (str): Indicates a description of datapath.
			DatapathId (str): Indicates the Datapath ID of the OpenFlow switch.
			DatapathIdInHex (str): Indicates the Datapath ID in hexadecimal format.
			Description (str): A description for the object.
			Enable (bool): If true, the object is enabled.
			EnableCalculatePacketOutRxRate (bool): If enabled packet_out rx rate and packet_in tx rate will be caculated for the switch and shown in Aggregated Switch Statistics and Switch Learned Info. This field can be enabled only if Calculate PacketIn Reply Delay is disabled for the switch.
			EnableHelloElement (bool): If true, enables Hello element for version negotiation.
			HardwareDescription (str): Indicates the hardware description of the switch.
			InterPacketInBurstGap (number): Indicates the duration, in milliseconds, to wait between successive Packet-In bursts.
			ManufacturerDescription (str): Indicates the description of the switch manufacturer.
			MaxPacketInBytes (number): Specifies the max amount of data to be sent in the Packet-In message.
			MaximumColorValue (number): Specify the maximum color value supported.The minimum value is 0 and the maximum value is 160. The default value is 50.
			MaximumNoOfBandsPerMeter (number): Specify the maximum number of bands supported per meter. The minimum value is 0 and the maximum value is 160. The default value is 50.
			MaximumNoOfBucketsPerGroup (number): Specify the maximum number of Buckets supported per group.The minimum value is 1 and the maximum value is 4092.The default value is 4092.
			MaximumNoOfMeters (number): Specify the maximum number of meters supported. The default value is 1000.
			NumberOfBuffers (number): Indicates the maximum number of packets that can be stored in the buffered at a time.
			PacketInReplyTimeout (number): Indicates the duration for which the Switch should wait for Packet-in-reply before freeing the buffer.
			PacketInTxBurstSize (number): Indicates the number of packets in messages sent in a single burst.
			SerialNumber (str): Indicates the Serial Number of the switch.
			SoftwareDescription (str): Indicates the description of the software installed on the switch.
			StoreFlows (bool): If true, the switch will store the flows advertised by the controller in its tables.
			SupportPacketForwarding (bool): If true, indicates that Packet Forwarding is supported on the OpenFlow switch.
			TableMissAction (str(drop|sendToController)): Specify what the Switch should do when there is no match for the packets.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, BarrierReplyDelay=None, BarrierReplyDelayType=None, BarrierReplyMaxDelay=None, CalculateControllerFlowTxRate=None, CalculatePacketInReplyDelay=None, DatapathDescription=None, DatapathId=None, DatapathIdInHex=None, Description=None, Enable=None, EnableCalculatePacketOutRxRate=None, EnableHelloElement=None, HardwareDescription=None, InterPacketInBurstGap=None, ManufacturerDescription=None, MaxPacketInBytes=None, MaximumColorValue=None, MaximumNoOfBandsPerMeter=None, MaximumNoOfBucketsPerGroup=None, MaximumNoOfMeters=None, NumberOfBuffers=None, PacketInReplyTimeout=None, PacketInTxBurstSize=None, SerialNumber=None, SoftwareDescription=None, StoreFlows=None, SupportPacketForwarding=None, TableMissAction=None):
		"""Adds a new switch node on the server and retrieves it in this instance.

		Args:
			BarrierReplyDelay (number): Indicates the delay between successive barrier notifications.
			BarrierReplyDelayType (str(fixed|random)): Select the delay type supported for barrier reply messages
			BarrierReplyMaxDelay (number): Indicates the delay between successive barrier notifications.
			CalculateControllerFlowTxRate (bool): If true, the Flow Rate of the controller is calculated.
			CalculatePacketInReplyDelay (bool): If true, calculates delay between Packet-In sent from Switch and reply received from Controller.
			DatapathDescription (str): Indicates a description of datapath.
			DatapathId (str): Indicates the Datapath ID of the OpenFlow switch.
			DatapathIdInHex (str): Indicates the Datapath ID in hexadecimal format.
			Description (str): A description for the object.
			Enable (bool): If true, the object is enabled.
			EnableCalculatePacketOutRxRate (bool): If enabled packet_out rx rate and packet_in tx rate will be caculated for the switch and shown in Aggregated Switch Statistics and Switch Learned Info. This field can be enabled only if Calculate PacketIn Reply Delay is disabled for the switch.
			EnableHelloElement (bool): If true, enables Hello element for version negotiation.
			HardwareDescription (str): Indicates the hardware description of the switch.
			InterPacketInBurstGap (number): Indicates the duration, in milliseconds, to wait between successive Packet-In bursts.
			ManufacturerDescription (str): Indicates the description of the switch manufacturer.
			MaxPacketInBytes (number): Specifies the max amount of data to be sent in the Packet-In message.
			MaximumColorValue (number): Specify the maximum color value supported.The minimum value is 0 and the maximum value is 160. The default value is 50.
			MaximumNoOfBandsPerMeter (number): Specify the maximum number of bands supported per meter. The minimum value is 0 and the maximum value is 160. The default value is 50.
			MaximumNoOfBucketsPerGroup (number): Specify the maximum number of Buckets supported per group.The minimum value is 1 and the maximum value is 4092.The default value is 4092.
			MaximumNoOfMeters (number): Specify the maximum number of meters supported. The default value is 1000.
			NumberOfBuffers (number): Indicates the maximum number of packets that can be stored in the buffered at a time.
			PacketInReplyTimeout (number): Indicates the duration for which the Switch should wait for Packet-in-reply before freeing the buffer.
			PacketInTxBurstSize (number): Indicates the number of packets in messages sent in a single burst.
			SerialNumber (str): Indicates the Serial Number of the switch.
			SoftwareDescription (str): Indicates the description of the software installed on the switch.
			StoreFlows (bool): If true, the switch will store the flows advertised by the controller in its tables.
			SupportPacketForwarding (bool): If true, indicates that Packet Forwarding is supported on the OpenFlow switch.
			TableMissAction (str(drop|sendToController)): Specify what the Switch should do when there is no match for the packets.

		Returns:
			self: This instance with all currently retrieved switch data using find and the newly added switch data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the switch data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, BarrierReplyDelay=None, BarrierReplyDelayType=None, BarrierReplyMaxDelay=None, CalculateControllerFlowTxRate=None, CalculatePacketInReplyDelay=None, DatapathDescription=None, DatapathId=None, DatapathIdInHex=None, Description=None, Enable=None, EnableCalculatePacketOutRxRate=None, EnableHelloElement=None, HardwareDescription=None, InterPacketInBurstGap=None, LocalIp=None, ManufacturerDescription=None, MaxPacketInBytes=None, MaximumColorValue=None, MaximumNoOfBandsPerMeter=None, MaximumNoOfBucketsPerGroup=None, MaximumNoOfMeters=None, NumberOfBuffers=None, PacketInReplyTimeout=None, PacketInTxBurstSize=None, SerialNumber=None, SoftwareDescription=None, StoreFlows=None, SupportPacketForwarding=None, TableMissAction=None):
		"""Finds and retrieves switch data from the server.

		All named parameters support regex and can be used to selectively retrieve switch data from the server.
		By default the find method takes no parameters and will retrieve all switch data from the server.

		Args:
			BarrierReplyDelay (number): Indicates the delay between successive barrier notifications.
			BarrierReplyDelayType (str(fixed|random)): Select the delay type supported for barrier reply messages
			BarrierReplyMaxDelay (number): Indicates the delay between successive barrier notifications.
			CalculateControllerFlowTxRate (bool): If true, the Flow Rate of the controller is calculated.
			CalculatePacketInReplyDelay (bool): If true, calculates delay between Packet-In sent from Switch and reply received from Controller.
			DatapathDescription (str): Indicates a description of datapath.
			DatapathId (str): Indicates the Datapath ID of the OpenFlow switch.
			DatapathIdInHex (str): Indicates the Datapath ID in hexadecimal format.
			Description (str): A description for the object.
			Enable (bool): If true, the object is enabled.
			EnableCalculatePacketOutRxRate (bool): If enabled packet_out rx rate and packet_in tx rate will be caculated for the switch and shown in Aggregated Switch Statistics and Switch Learned Info. This field can be enabled only if Calculate PacketIn Reply Delay is disabled for the switch.
			EnableHelloElement (bool): If true, enables Hello element for version negotiation.
			HardwareDescription (str): Indicates the hardware description of the switch.
			InterPacketInBurstGap (number): Indicates the duration, in milliseconds, to wait between successive Packet-In bursts.
			LocalIp (str): Indicates the local IP address of the interface. This field is auto-populated and cannot be changed.
			ManufacturerDescription (str): Indicates the description of the switch manufacturer.
			MaxPacketInBytes (number): Specifies the max amount of data to be sent in the Packet-In message.
			MaximumColorValue (number): Specify the maximum color value supported.The minimum value is 0 and the maximum value is 160. The default value is 50.
			MaximumNoOfBandsPerMeter (number): Specify the maximum number of bands supported per meter. The minimum value is 0 and the maximum value is 160. The default value is 50.
			MaximumNoOfBucketsPerGroup (number): Specify the maximum number of Buckets supported per group.The minimum value is 1 and the maximum value is 4092.The default value is 4092.
			MaximumNoOfMeters (number): Specify the maximum number of meters supported. The default value is 1000.
			NumberOfBuffers (number): Indicates the maximum number of packets that can be stored in the buffered at a time.
			PacketInReplyTimeout (number): Indicates the duration for which the Switch should wait for Packet-in-reply before freeing the buffer.
			PacketInTxBurstSize (number): Indicates the number of packets in messages sent in a single burst.
			SerialNumber (str): Indicates the Serial Number of the switch.
			SoftwareDescription (str): Indicates the description of the software installed on the switch.
			StoreFlows (bool): If true, the switch will store the flows advertised by the controller in its tables.
			SupportPacketForwarding (bool): If true, indicates that Packet Forwarding is supported on the OpenFlow switch.
			TableMissAction (str(drop|sendToController)): Specify what the Switch should do when there is no match for the packets.

		Returns:
			self: This instance with matching switch data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of switch data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the switch data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class IsisMappingServerIPV4List(Base):
	"""The IsisMappingServerIPV4List class encapsulates a required isisMappingServerIPV4List node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the IsisMappingServerIPV4List property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'isisMappingServerIPV4List'

	def __init__(self, parent):
		super(IsisMappingServerIPV4List, self).__init__(parent)

	@property
	def AFlag(self):
		"""Attached flag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('aFlag')

	@property
	def Active(self):
		"""Activate/Deactivate Configuration

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('active')

	@property
	def Algorithm(self):
		"""Algorithm

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('algorithm')

	@property
	def Count(self):
		"""Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DFlag(self):
		"""When the SID/Label Binding TLV is leaked from level-2 to level-1, this flag MUST be set, else it should be clear

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('dFlag')

	@property
	def DescriptiveName(self):
		"""Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def EFlag(self):
		"""Explicit NULL flag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('eFlag')

	@property
	def FECPrefix(self):
		"""IPv4 FEC Prefix

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('fECPrefix')

	@property
	def LFlag(self):
		"""Local Flag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('lFlag')

	@property
	def LastFECAddress(self):
		"""Last IPv4 FEC Address

		Returns:
			list(str)
		"""
		return self._get_attribute('lastFECAddress')

	@property
	def MFlag(self):
		"""Mirror Context flag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('mFlag')

	@property
	def NFlag(self):
		"""N Flag: Indicates the nodal prefix

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('nFlag')

	@property
	def Name(self):
		"""Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def PFlag(self):
		"""P Flag: Indicates that to reach to a prefix, this router would be penultimate hop.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('pFlag')

	@property
	def PrefixLength(self):
		"""Length of the IPv4 FEC prefix

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('prefixLength')

	@property
	def RFlag(self):
		"""Redistribution flag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('rFlag')

	@property
	def Range(self):
		"""This the count of continuous IPv4 address prefixes and their respective continuous SID/labels

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('range')

	@property
	def SFlag(self):
		"""Enabling this flag lets the SID/Label Binding TLV to get flooded across the entire routing domain, else this TLV should not be leaked between levels

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sFlag')

	@property
	def StartSIDLabel(self):
		"""Starting value of SID/ Label

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('startSIDLabel')

	@property
	def VFlag(self):
		"""Value Flag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('vFlag')

	@property
	def Weight(self):
		"""Weight

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('weight')

	def update(self, Name=None):
		"""Updates a child instance of isisMappingServerIPV4List on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def get_device_ids(self, PortNames=None, AFlag=None, Active=None, Algorithm=None, DFlag=None, EFlag=None, FECPrefix=None, LFlag=None, MFlag=None, NFlag=None, PFlag=None, PrefixLength=None, RFlag=None, Range=None, SFlag=None, StartSIDLabel=None, VFlag=None, Weight=None):
		"""Base class infrastructure that gets a list of isisMappingServerIPV4List device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			AFlag (str): optional regex of aFlag
			Active (str): optional regex of active
			Algorithm (str): optional regex of algorithm
			DFlag (str): optional regex of dFlag
			EFlag (str): optional regex of eFlag
			FECPrefix (str): optional regex of fECPrefix
			LFlag (str): optional regex of lFlag
			MFlag (str): optional regex of mFlag
			NFlag (str): optional regex of nFlag
			PFlag (str): optional regex of pFlag
			PrefixLength (str): optional regex of prefixLength
			RFlag (str): optional regex of rFlag
			Range (str): optional regex of range
			SFlag (str): optional regex of sFlag
			StartSIDLabel (str): optional regex of startSIDLabel
			VFlag (str): optional regex of vFlag
			Weight (str): optional regex of weight

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def Advertise(self, *args, **kwargs):
		"""Executes the advertise operation on the server.

		Advertise the V4 Mapping Server Range TLVs

		advertise(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin.An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('advertise', payload=payload, response_object=None)

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)

	def Withdraw(self, *args, **kwargs):
		"""Executes the withdraw operation on the server.

		Withdraw the V4 Mapping Server Range TLVs

		withdraw(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin.An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('withdraw', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Ipv6sr(Base):
	"""The Ipv6sr class encapsulates a user managed ipv6sr node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Ipv6sr property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'ipv6sr'

	def __init__(self, parent):
		super(Ipv6sr, self).__init__(parent)

	@property
	def IPv6SegmentsList(self):
		"""An instance of the IPv6SegmentsList class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ipv6segmentslist.IPv6SegmentsList)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ipv6segmentslist import IPv6SegmentsList
		return IPv6SegmentsList(self)

	@property
	def Connector(self):
		"""An instance of the Connector class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.connector.Connector)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.connector import Connector
		return Connector(self)

	@property
	def Active(self):
		"""Activate/Deactivate Configuration

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('active')

	@property
	def CleanupFlag(self):
		"""Set when the SRH has to be removed from the packet when the packet reaches the last segment

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('cleanupFlag')

	@property
	def ConnectedVia(self):
		"""DEPRECATED List of layers this layer used to connect to the wire

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])
		"""
		return self._get_attribute('connectedVia')
	@ConnectedVia.setter
	def ConnectedVia(self, value):
		self._set_attribute('connectedVia', value)

	@property
	def Count(self):
		"""DEPRECATED Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DescriptiveName(self):
		"""DEPRECATED Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def Errors(self):
		"""DEPRECATED A list of errors that have occurred

		Returns:
			list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/?deepchild=*],arg2:list[str]))
		"""
		return self._get_attribute('errors')

	@property
	def FirstSegment(self):
		"""DEPRECATED Count of enabled SID List -1

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('firstSegment')

	@property
	def Multiplier(self):
		"""DEPRECATED Number of layer instances per parent instance (multiplier)

		Returns:
			number
		"""
		return self._get_attribute('multiplier')
	@Multiplier.setter
	def Multiplier(self, value):
		self._set_attribute('multiplier', value)

	@property
	def Name(self):
		"""DEPRECATED Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def NumberSegments(self):
		"""DEPRECATED Maximum available index of the Segments List in SRH header (0 Based Index)

		Returns:
			number
		"""
		return self._get_attribute('numberSegments')
	@NumberSegments.setter
	def NumberSegments(self, value):
		self._set_attribute('numberSegments', value)

	@property
	def OamFlag(self):
		"""DEPRECATED Indicates that this packet will be Operations And Management

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('oamFlag')

	@property
	def OuterDestAddr(self):
		"""DEPRECATED Controlled by Segments Left, index from enabled SID List

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('outerDestAddr')

	@property
	def OuterSrcAddr(self):
		"""DEPRECATED Outer IPv6 Source Address

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('outerSrcAddr')

	@property
	def ProtectedFlag(self):
		"""DEPRECATED Set when the packet has been rerouted through FRR mechanism by an SR endpoint node

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('protectedFlag')

	@property
	def SID0(self):
		"""DEPRECATED Segment Item Address

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sID0')

	@property
	def SIDEnable0(self):
		"""DEPRECATED Enable This Segment

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sIDEnable0')

	@property
	def SegmentsLeft(self):
		"""DEPRECATED Segments Left (0 Based Index)

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('segmentsLeft')

	@property
	def SessionStatus(self):
		"""DEPRECATED Current state of protocol session: Not Started - session negotiation not started, the session is not active yet. Down - actively trying to bring up a protocol session, but negotiation is didn't successfully complete (yet). Up - session came up successfully.

		Returns:
			list(str[down|notStarted|up])
		"""
		return self._get_attribute('sessionStatus')

	@property
	def StackedLayers(self):
		"""DEPRECATED List of secondary (many to one) child layer protocols

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])
		"""
		return self._get_attribute('stackedLayers')
	@StackedLayers.setter
	def StackedLayers(self, value):
		self._set_attribute('stackedLayers', value)

	@property
	def StateCounts(self):
		"""DEPRECATED A list of values that indicates the total number of sessions, the number of sessions not started, the number of sessions down and the number of sessions that are up

		Returns:
			dict(total:number,notStarted:number,down:number,up:number)
		"""
		return self._get_attribute('stateCounts')

	@property
	def Status(self):
		"""DEPRECATED Running status of associated network element. Once in Started state, protocol sessions will begin to negotiate.

		Returns:
			str(configured|error|mixed|notStarted|started|starting|stopping)
		"""
		return self._get_attribute('status')

	@property
	def TunnelDescription(self):
		"""DEPRECATED Tunnel Description

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('tunnelDescription')

	@property
	def UseAsIngress(self):
		"""DEPRECATED Use This Device As Ingress

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('useAsIngress')

	def update(self, ConnectedVia=None, Multiplier=None, Name=None, NumberSegments=None, StackedLayers=None):
		"""Updates a child instance of ipv6sr on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			NumberSegments (number): Maximum available index of the Segments List in SRH header (0 Based Index)
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, ConnectedVia=None, Multiplier=None, Name=None, NumberSegments=None, StackedLayers=None):
		"""Adds a new ipv6sr node on the server and retrieves it in this instance.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			NumberSegments (number): Maximum available index of the Segments List in SRH header (0 Based Index)
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols

		Returns:
			self: This instance with all currently retrieved ipv6sr data using find and the newly added ipv6sr data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the ipv6sr data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, ConnectedVia=None, Count=None, DescriptiveName=None, Errors=None, Multiplier=None, Name=None, NumberSegments=None, SessionStatus=None, StackedLayers=None, StateCounts=None, Status=None):
		"""Finds and retrieves ipv6sr data from the server.

		All named parameters support regex and can be used to selectively retrieve ipv6sr data from the server.
		By default the find method takes no parameters and will retrieve all ipv6sr data from the server.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group
			DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context
			Errors (list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/?deepchild=*],arg2:list[str]))): A list of errors that have occurred
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			NumberSegments (number): Maximum available index of the Segments List in SRH header (0 Based Index)
			SessionStatus (list(str[down|notStarted|up])): Current state of protocol session: Not Started - session negotiation not started, the session is not active yet. Down - actively trying to bring up a protocol session, but negotiation is didn't successfully complete (yet). Up - session came up successfully.
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols
			StateCounts (dict(total:number,notStarted:number,down:number,up:number)): A list of values that indicates the total number of sessions, the number of sessions not started, the number of sessions down and the number of sessions that are up
			Status (str(configured|error|mixed|notStarted|started|starting|stopping)): Running status of associated network element. Once in Started state, protocol sessions will begin to negotiate.

		Returns:
			self: This instance with matching ipv6sr data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of ipv6sr data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the ipv6sr data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def get_device_ids(self, PortNames=None, Active=None, CleanupFlag=None, FirstSegment=None, OamFlag=None, OuterDestAddr=None, OuterSrcAddr=None, ProtectedFlag=None, SID0=None, SIDEnable0=None, SegmentsLeft=None, TunnelDescription=None, UseAsIngress=None):
		"""Base class infrastructure that gets a list of ipv6sr device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			Active (str): optional regex of active
			CleanupFlag (str): optional regex of cleanupFlag
			FirstSegment (str): optional regex of firstSegment
			OamFlag (str): optional regex of oamFlag
			OuterDestAddr (str): optional regex of outerDestAddr
			OuterSrcAddr (str): optional regex of outerSrcAddr
			ProtectedFlag (str): optional regex of protectedFlag
			SID0 (str): optional regex of sID0
			SIDEnable0 (str): optional regex of sIDEnable0
			SegmentsLeft (str): optional regex of segmentsLeft
			TunnelDescription (str): optional regex of tunnelDescription
			UseAsIngress (str): optional regex of useAsIngress

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)

	def RestartDown(self, *args, **kwargs):
		"""Executes the restartDown operation on the server.

		Stop and start interfaces and sessions that are in Down state.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		restartDown()

		restartDown(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		restartDown(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('restartDown', payload=payload, response_object=None)

	def Start(self, *args, **kwargs):
		"""Executes the start operation on the server.

		Start selected protocols.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		start()

		start(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		start(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('start', payload=payload, response_object=None)

	def Stop(self, *args, **kwargs):
		"""Executes the stop operation on the server.

		Stop selected protocols.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		stop()

		stop(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		stop(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('stop', payload=payload, response_object=None)
